inspired from https://github.com/wehkamp/docker-prometheus-cloudflare-exporter

How to build
============
::

 virtualenv -p python3 .venv
 source .venv/bin/activate
 pip install -r requirements.txt; pip install -r tests-requirements.txt; pip install -e .
